/* SPDX-License-Identifier: GPL-2.0 */
/*
 * This header provides constants for configuring the AT91 SAMA5D2 ADC
 */

#ifndef _DT_BINDINGS_IIO_ADC_AT91_SAMA5D2_ADC_H
#define _DT_BINDINGS_IIO_ADC_AT91_SAMA5D2_ADC_H

/* X relative position channel index */
#define AT91_SAMA5D2_ADC_X_CHANNEL		24
/* Y relative position channel index */
#define AT91_SAMA5D2_ADC_Y_CHANNEL		25
/* pressure channel index */
#define AT91_SAMA5D2_ADC_P_CHANNEL		26

#endif
